==> kbibtex-0.1.1.tar.bz2: kbibtex-0.1.1/src/kbibtexlistviewitem.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef KBIBTEXLISTVIEWITEM_H
#define KBIBTEXLISTVIEWITEM_H

#include <klistview.h>

class BibTeXElement;

class KBibTeXListViewItem : public KListViewItem
{
public:
    KBibTeXListViewItem( BibTeXElement *element, QListView *parent );
    KBibTeXListViewItem( BibTeXElement *element, QListView *parent, QListViewItem *after );

    ~KBibTeXListViewItem();

    BibTeXElement* element();
    void updateItem();

private:
    BibTeXElement *m_element;

    void setTexts();
};

#endif

==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/kbibtexlistviewitem.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef KBIBTEXLISTVIEWITEM_H
#define KBIBTEXLISTVIEWITEM_H

#include <klistview.h>

#include <bibtexelement.h>

class KBibTeXListViewItem : public KListViewItem
{
public:
    KBibTeXListViewItem( BibTeX::BibTeXElement *element, QListView *parent );
    KBibTeXListViewItem( BibTeX::BibTeXElement *element, QListView *parent, QListViewItem *after );

    ~KBibTeXListViewItem();

    BibTeX::BibTeXElement* element();
    void updateItem();

private:
    BibTeX::BibTeXElement *m_element;

    void setTexts();
};

#endif
